@@ -6,7 +6,7 @@
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.8.1.
+# This file is part of Merlin, Version: 1.8.2.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -33,6 +33,7 @@ from __future__ import absolute_import, print_function
 
 import logging
 import os
+from typing import Dict, Optional, Union
 
 import billiard
 import psutil
@@ -47,41 +48,41 @@ from merlin.router import route_for_task
 from merlin.utils import nested_namespace_to_dicts
 
 
-LOG = logging.getLogger(__name__)
+LOG: logging.Logger = logging.getLogger(__name__)
 
 merlin.common.security.encrypt_backend_traffic.set_backend_funcs()
 
 
-broker_ssl = True
-results_ssl = False
+BROKER_SSL: bool = True
+RESULTS_SSL: bool = False
+BROKER_URI: Optional[str] = ""
+RESULTS_BACKEND_URI: Optional[str] = ""
 try:
     BROKER_URI = broker.get_connection_string()
-    LOG.debug(f"broker: {broker.get_connection_string(include_password=False)}")
-    broker_ssl = broker.get_ssl_config()
-    LOG.debug(f"broker_ssl = {broker_ssl}")
+    LOG.debug("broker: %s", broker.get_connection_string(include_password=False))
+    BROKER_SSL = broker.get_ssl_config()
+    LOG.debug("broker_ssl = %s", BROKER_SSL)
     RESULTS_BACKEND_URI = results_backend.get_connection_string()
-    results_ssl = results_backend.get_ssl_config(celery_check=True)
-    LOG.debug(
-        f"results: {results_backend.get_connection_string(include_password=False)}"
-    )
-    LOG.debug(f"results: redis_backed_use_ssl = {results_ssl}")
+    RESULTS_SSL = results_backend.get_ssl_config(celery_check=True)
+    LOG.debug("results: %s", results_backend.get_connection_string(include_password=False))
+    LOG.debug("results: redis_backed_use_ssl = %s", RESULTS_SSL)
 except ValueError:
     # These variables won't be set if running with '--local'.
     BROKER_URI = None
     RESULTS_BACKEND_URI = None
 
 # initialize app with essential properties
-app = Celery(
+app: Celery = Celery(
     "merlin",
     broker=BROKER_URI,
     backend=RESULTS_BACKEND_URI,
-    broker_use_ssl=broker_ssl,
-    redis_backend_use_ssl=results_ssl,
+    broker_use_ssl=BROKER_SSL,
+    redis_backend_use_ssl=RESULTS_SSL,
     task_routes=(route_for_task,),
 )
 
 # set task priority defaults to prioritize workflow tasks over task-expansion tasks
-task_priority_defaults = {
+task_priority_defaults: Dict[str, Union[int, Priority]] = {
     "task_queue_max_priority": 10,
     "task_default_priority": get_priority(Priority.mid),
 }
@@ -97,15 +98,15 @@ app.conf.update(**celeryconfig.DICT)
 
 # load config overrides from app.yaml
 if (
-    (not hasattr(CONFIG.celery, "override"))
+    not hasattr(CONFIG.celery, "override")
     or (CONFIG.celery.override is None)
-    or (len(nested_namespace_to_dicts(CONFIG.celery.override)) == 0)
+    or (not nested_namespace_to_dicts(CONFIG.celery.override))  # only true if len == 0
 ):
     LOG.debug("Skipping celery config override; 'celery.override' field is empty.")
 else:
-    override_dict = nested_namespace_to_dicts(CONFIG.celery.override)
-    override_str = ""
-    i = 0
+    override_dict: Dict = nested_namespace_to_dicts(CONFIG.celery.override)
+    override_str: str = ""
+    i: int = 0
     for k, v in override_dict.items():
         if k not in str(app.conf.__dict__):
             raise ValueError(f"'{k}' is not a celery configuration.")
@@ -114,7 +115,8 @@ else:
             override_str += "\n"
         i += 1
     LOG.info(
-        f"Overriding default celery config with 'celery.override' in 'app.yaml':\n{override_str}"
+        "Overriding default celery config with 'celery.override' in 'app.yaml':\n%s",
+        override_str,
     )
     app.conf.update(**override_dict)
 
@@ -122,8 +124,9 @@ else:
 app.autodiscover_tasks(["merlin.common"])
 
 
+# Pylint believes the args are unused, I believe they're used after decoration
 @worker_process_init.connect()
-def setup(**kwargs):
+def setup(**kwargs):  # pylint: disable=W0613
     """
     Set affinity for the worker on startup (works on toss3 nodes)
 
@@ -131,10 +134,12 @@ def setup(**kwargs):
     """
     if "CELERY_AFFINITY" in os.environ and int(os.environ["CELERY_AFFINITY"]) > 1:
         # Number of cpus between workers.
-        cpu_skip = int(os.environ["CELERY_AFFINITY"])
-        npu = psutil.cpu_count()
-        p = psutil.Process()
-        current = billiard.current_process()
-        prefork_id = current._identity[0] - 1  # range 0:nworkers-1
-        cpu_slot = (prefork_id * cpu_skip) % npu
-        p.cpu_affinity(list(range(cpu_slot, cpu_slot + cpu_skip)))
+        cpu_skip: int = int(os.environ["CELERY_AFFINITY"])
+        npu: int = psutil.cpu_count()
+        process: psutil.Process = psutil.Process()
+        # pylint is upset that typing accesses a protected class, ignoring W0212
+        # pylint is upset that billiard doesn't have a current_process() method - it does
+        current: billiard.process._MainProcess = billiard.current_process()  # pylint: disable=W0212, E1101
+        prefork_id: int = current._identity[0] - 1  # pylint: disable=W0212  # range 0:nworkers-1
+        cpu_slot: int = (prefork_id * cpu_skip) % npu
+        process.cpu_affinity(list(range(cpu_slot, cpu_slot + cpu_skip)))
