@@ -18,18 +18,10 @@ def process_args(args):
 
 def setup_argparse():
     parser = argparse.ArgumentParser(description="Process some integers.")
-    parser.add_argument(
-        "X", metavar="X", type=float, help="The x dimension of the sample."
-    )
-    parser.add_argument(
-        "Y", metavar="Y", type=float, help="The y dimension of the sample."
-    )
-    parser.add_argument(
-        "Z", metavar="Z", type=float, help="The z dimension of the sample."
-    )
-    parser.add_argument(
-        "-outfile", help="Output file name", default="hello_world_output.json"
-    )
+    parser.add_argument("X", metavar="X", type=float, help="The x dimension of the sample.")
+    parser.add_argument("Y", metavar="Y", type=float, help="The y dimension of the sample.")
+    parser.add_argument("Z", metavar="Z", type=float, help="The z dimension of the sample.")
+    parser.add_argument("-outfile", help="Output file name", default="hello_world_output.json")
     return parser
 
 
