@@ -2,16 +2,13 @@ import argparse
 import glob
 
 import numpy as np
-
 import Ofpp
 
 
 descript = """Using parameters to edit OpenFOAM parameters"""
 parser = argparse.ArgumentParser(description=descript)
 
-parser.add_argument(
-    "-data", "--data_dir", help="The home directory of the data directories"
-)
+parser.add_argument("-data", "--data_dir", help="The home directory of the data directories")
 parser.add_argument("-merlin_paths", nargs="+", help="The path of all merlin runs")
 
 args = parser.parse_args()
@@ -38,8 +35,6 @@ for i, dir_name in enumerate(dir_names):
 
 resolution = np.array(enstrophy).shape[-1]
 U = np.array(U).reshape(len(dir_names), num_of_timesteps, resolution, 3)
-enstrophy = np.array(enstrophy).reshape(
-    len(dir_names), num_of_timesteps, resolution
-) / float(resolution)
+enstrophy = np.array(enstrophy).reshape(len(dir_names), num_of_timesteps, resolution) / float(resolution)
 
 np.savez("data.npz", U, enstrophy)
