@@ -254,43 +254,27 @@ class TestMerlinStudy(unittest.TestCase):
         object, the MerlinStudy should produce a new spec with all instances
         of $(OUTPUT_PATH), $(SPECROOT), and env labels and variables expanded.
         """
-        assert TestMerlinStudy.file_contains_string(
-            self.merlin_spec_filepath, "$(SPECROOT)"
-        )
-        assert TestMerlinStudy.file_contains_string(
-            self.merlin_spec_filepath, "$(OUTPUT_PATH)"
-        )
+        assert TestMerlinStudy.file_contains_string(self.merlin_spec_filepath, "$(SPECROOT)")
+        assert TestMerlinStudy.file_contains_string(self.merlin_spec_filepath, "$(OUTPUT_PATH)")
         assert TestMerlinStudy.file_contains_string(self.merlin_spec_filepath, "$PATH")
 
-        assert not TestMerlinStudy.file_contains_string(
-            self.study.expanded_spec.path, "$(SPECROOT)"
-        )
-        assert not TestMerlinStudy.file_contains_string(
-            self.study.expanded_spec.path, "$(OUTPUT_PATH)"
-        )
-        assert TestMerlinStudy.file_contains_string(
-            self.study.expanded_spec.path, "$PATH"
-        )
-        assert not TestMerlinStudy.file_contains_string(
-            self.study.expanded_spec.path, "PATH_VAR: $PATH"
-        )
+        assert not TestMerlinStudy.file_contains_string(self.study.expanded_spec.path, "$(SPECROOT)")
+        assert not TestMerlinStudy.file_contains_string(self.study.expanded_spec.path, "$(OUTPUT_PATH)")
+        assert TestMerlinStudy.file_contains_string(self.study.expanded_spec.path, "$PATH")
+        assert not TestMerlinStudy.file_contains_string(self.study.expanded_spec.path, "PATH_VAR: $PATH")
 
     def test_column_label_conflict(self):
         """
         If there is a common key between Maestro's global.parameters and
         Merlin's sample/column_labels, an error should be raised.
         """
-        merlin_spec_conflict: str = os.path.join(
-            self.tmpdir, "basic_ensemble_conflict.yaml"
-        )
+        merlin_spec_conflict: str = os.path.join(self.tmpdir, "basic_ensemble_conflict.yaml")
         with open(merlin_spec_conflict, "w+") as _file:
             _file.write(MERLIN_SPEC_CONFLICT)
         # for some reason flake8 doesn't believe variables instantiated inside the try/with context are assigned
         with pytest.raises(ValueError):
             study_conflict: MerlinStudy = MerlinStudy(merlin_spec_conflict)
-            assert (
-                not study_conflict
-            ), "study_conflict completed construction without raising a ValueError."
+            assert not study_conflict, "study_conflict completed construction without raising a ValueError."
 
     # TODO the pertinent attribute for study_no_env should be examined and asserted to be empty
     def test_no_env(self):
@@ -298,18 +282,12 @@ class TestMerlinStudy(unittest.TestCase):
         A MerlinStudy should be able to support a MerlinSpec that does not contain
         the optional `env` section.
         """
-        merlin_spec_no_env_filepath: str = os.path.join(
-            self.tmpdir, "basic_ensemble_no_env.yaml"
-        )
+        merlin_spec_no_env_filepath: str = os.path.join(self.tmpdir, "basic_ensemble_no_env.yaml")
         with open(merlin_spec_no_env_filepath, "w+") as _file:
             _file.write(MERLIN_SPEC_NO_ENV)
         try:
             study_no_env: MerlinStudy = MerlinStudy(merlin_spec_no_env_filepath)
-            bad_type_err: str = (
-                f"study_no_env failed construction, is type {type(study_no_env)}."
-            )
+            bad_type_err: str = f"study_no_env failed construction, is type {type(study_no_env)}."
             assert isinstance(study_no_env, MerlinStudy), bad_type_err
         except Exception as e:
-            assert (
-                False
-            ), f"Encountered unexpected exception, {e}, for viable MerlinSpec without optional 'env' section."
+            assert False, f"Encountered unexpected exception, {e}, for viable MerlinSpec without optional 'env' section."
